@@ -247,6 +247,10 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 				: getSchemaDirectory();
 	}
 
+	/**
+	 * The source directory containing <code>*.cat</code> catalog files. Defaults to the <code>schemaDirectory</code>.
+	 */
+	@Parameter(property = "maven.xjc2.catalogDirectory")
 	private File catalogDirectory;
 
 	public void setCatalogDirectory(File catalogDirectory) {
@@ -345,6 +349,18 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 		this.catalog = catalog;
 	}
 
+	/**
+	 * <p>
+	 * A list of regular expression file search patterns to specify the catalogs
+	 * to be processed. Searching is based from the root of
+	 * <code>catalogDirectory</code>.
+	 * </p>
+	 * <p>
+	 * If left undefined, then all <code>*.cat</code> files in
+	 * <code>catalogDirectory</code> will be processed.
+	 * </p>
+	 */
+	@Parameter
 	private String[] catalogIncludes = new String[] { "*.cat" };
 
 	public String[] getCatalogIncludes() {
@@ -355,6 +371,12 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 		this.catalogIncludes = catalogIncludes;
 	}
 
+	/**
+	 * A list of regular expression file search patterns to specify the catalogs
+	 * to be excluded from the <code>catalogIncludes</code> list. Searching is
+	 * based from the root of <code>catalogDirectory</code>.
+	 */
+	@Parameter
 	private String[] catalogExcludes;
 
 	public String[] getCatalogExcludes() {
@@ -598,14 +620,28 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 	public void setAccessExternalDTD(String accessExternalDTD) {
 		this.accessExternalDTD = accessExternalDTD;
 	}
+	
+	/**
+	 * Enables external entity processing.
+	 */
+	@Parameter(defaultValue = "true", property = "maven.xjc2.enableExternalEntityProcessing")
+	private boolean enableExternalEntityProcessing;
+	
+	public boolean isEnableExternalEntityProcessing() {
+		return enableExternalEntityProcessing;
+	}
+	
+	public void setEnableExternalEntityProcessing(boolean enableExternalEntityProcessing) {
+		this.enableExternalEntityProcessing = enableExternalEntityProcessing;
+	}
 
 	/**
-	 * If 'true', generates content property for types with multiple xs:any
-	 * derived elements; xjc's -contentForWildcard option.
+	 * If <code>true</code>, generates content property for types with multiple <code>xs:any</code>
+	 * derived elements; corresponds to the XJC <code>-contentForWildcard</code> option.
 	 */
+	@Parameter(defaultValue="false")
 	private boolean contentForWildcard;
 
-	// TODO parameter.
 	public boolean getContentForWildcard() {
 		return contentForWildcard;
 	}
@@ -834,7 +870,7 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 	}
 
 	public void setOtherDependsExcludes(String[] otherDependsExcludes) {
-		this.otherDependsExcludes = catalogExcludes;
+		this.otherDependsExcludes = otherDependsExcludes;
 	}
 
 	/**
@@ -873,8 +909,8 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 	 * If <code>true</code> (default), adds <code>if-exists="true"</code>
 	 * attributes to the <code>bindings</code> elements associated with schemas
 	 * (via <code>scd="x-schema::..."</code>) in the generated episode files.
-	 * This is necessary to avoid the annoying <quote>SCD "x-schema::tns" didn't
-	 * match any schema component</quote> errors.
+	 * This is necessary to avoid the annoying `SCD "x-schema::tns" didn't
+	 * match any schema component` errors.
 	 */
 	@Parameter(property = "maven.xjc2.addIfExistsToEpisodeSchemaBindings", defaultValue = "true")
 	private boolean addIfExistsToEpisodeSchemaBindings = true;
@@ -1062,7 +1098,7 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 
 	private static final String XML_SCHEMA_CLASS_NAME = "XmlSchema";
 
-	@Component
+	@Parameter( defaultValue = "${project}", readonly = true )
 	private MavenProject project;
 
 	public MavenProject getProject() {
@@ -1286,7 +1322,7 @@ public abstract class AbstractXJC2Mojo<O> extends AbstractMojo implements
 			@SuppressWarnings("unchecked")
 			final Set<Artifact> artifacts = MavenMetadataSource
 					.createArtifacts(getArtifactFactory(),
-							Arrays.asList(dependencyResource),
+							Arrays.<Dependency>asList(dependencyResource),
 							Artifact.SCOPE_RUNTIME, null, getProject());
 
 			if (artifacts.size() != 1) {
