@@ -20,7 +20,6 @@ import java.io.InputStream;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
-import java.net.URLClassLoader;
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -35,6 +34,7 @@ import java.util.TreeMap;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 
+import javax.xml.bind.annotation.XmlSchema;
 import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerException;
@@ -78,6 +78,7 @@ import org.xml.sax.SAXException;
 
 import com.sun.org.apache.xml.internal.resolver.CatalogManager;
 import com.sun.org.apache.xml.internal.resolver.tools.CatalogResolver;
+import com.sun.xml.txw2.annotation.XmlNamespace;
 
 /**
  * Maven JAXB 2.x Mojo.
@@ -86,6 +87,8 @@ import com.sun.org.apache.xml.internal.resolver.tools.CatalogResolver;
  */
 public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 
+	private static final String JAXB_NSURI = "http://java.sun.com/xml/ns/jaxb";
+
 	public static final String ADD_IF_EXISTS_TO_EPISODE_SCHEMA_BINDINGS_TRANSFORMATION_RESOURCE_NAME = "/"
 			+ RawXJC2Mojo.class.getPackage().getName().replace('.', '/') + "/addIfExistsToEpisodeSchemaBindings.xslt";
 
@@ -324,8 +327,7 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 	}
 
 	/**
-	 * *************************************************************************
-	 * *
+	 * ************************************************************************* *
 	 */
 
 	protected void injectDependencyDefaults() {
@@ -423,6 +425,8 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 		setupLogging();
 		if (getVerbose())
 			getLog().info("Started execution.");
+		setupBindInfoPackage();
+		setupEpisodePackage();
 		setupMavenPaths();
 		setupCatalogResolver();
 		setupEntityResolver();
@@ -483,8 +487,62 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 		}
 	}
 
+	private void setupBindInfoPackage() {
+		String packageInfoClassName = "com.sun.tools.xjc.reader.xmlschema.bindinfo.package-info";
+		try {
+			final Class<?> packageInfoClass = Class.forName(packageInfoClassName);
+			final XmlSchema xmlSchema = packageInfoClass.getAnnotation(XmlSchema.class);
+			if (xmlSchema == null) {
+				getLog().warn(MessageFormat.format(
+						"Class [{0}] is missing the [{1}] annotation. Processing bindings will probably fail.",
+						packageInfoClassName, XmlSchema.class.getName()));
+			} else {
+				final String namespace = xmlSchema.namespace();
+				if (!JAXB_NSURI.equals(namespace)) {
+					getLog().warn(MessageFormat.format(
+							"Namespace of the [{0}] annotation is [{1}] and does not match [{2}]. Processing bindings will probably fail.",
+							namespace, XmlSchema.class.getName(), JAXB_NSURI));
+				}
+			}
+
+		} catch (ClassNotFoundException cnfex) {
+			getLog().warn(
+					MessageFormat.format("Class [{0}] could not be found. Processing bindings will probably faile.",
+							packageInfoClassName),
+					cnfex);
+		}
+
+	}
+
+	private void setupEpisodePackage() {
+		String packageInfoClassName = "com.sun.xml.bind.v2.schemagen.episode.package-info";
+		try {
+			final Class<?> packageInfoClass = Class.forName(packageInfoClassName);
+			final XmlNamespace xmlNamespace = packageInfoClass.getAnnotation(XmlNamespace.class);
+			if (xmlNamespace == null) {
+				getLog().warn(MessageFormat.format(
+						"Class [{0}] is missing the [{1}] annotation. Processing bindings will probably fail.",
+						packageInfoClassName, XmlNamespace.class.getName()));
+			} else {
+				final String namespace = xmlNamespace.value();
+				if (!JAXB_NSURI.equals(namespace)) {
+					getLog().warn(MessageFormat.format(
+							"Namespace of the [{0}] annotation is [{1}] and does not match [{2}]. Processing bindings will probably fail.",
+							XmlNamespace.class.getName(), namespace, JAXB_NSURI));
+				}
+			}
+
+		} catch (ClassNotFoundException cnfex) {
+			getLog().warn(
+					MessageFormat.format("Class [{0}] could not be found. Processing bindings will probably faile.",
+							packageInfoClassName),
+					cnfex);
+		}
+
+	}
+
 	private void addIfExistsToEpisodeSchemaBindings() throws MojoExecutionException {
-		if (!isAddIfExistsToEpisodeSchemaBindings()) {
+		if (!getEpisode() || !isAddIfExistsToEpisodeSchemaBindings()) {
 			return;
 		}
 		final File episodeFile = getEpisodeFile();
@@ -542,11 +600,10 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 	public abstract void doExecute(O options) throws MojoExecutionException;
 
 	/**
-	 * Initializes logging. If Maven is run in debug mode (that is, debug level
-	 * is enabled in the log), turn on the verbose mode in Mojo. Further on, if
-	 * vebose mode is on, set the
-	 * <code>com.sun.tools.xjc.Options.findServices</code> system property on to
-	 * enable debuggin of XJC plugins.
+	 * Initializes logging. If Maven is run in debug mode (that is, debug level is
+	 * enabled in the log), turn on the verbose mode in Mojo. Further on, if vebose
+	 * mode is on, set the <code>com.sun.tools.xjc.Options.findServices</code>
+	 * system property on to enable debuggin of XJC plugins.
 	 * 
 	 */
 	protected void setupLogging() {
@@ -711,8 +768,8 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 	}
 
 	/**
-	 * Log the configuration settings. Shown when exception thrown or when
-	 * verbose is true.
+	 * Log the configuration settings. Shown when exception thrown or when verbose
+	 * is true.
 	 */
 	protected void logConfiguration() throws MojoExecutionException {
 		super.logConfiguration();
@@ -746,41 +803,28 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 
 		for (Artifact artifact : compileScopeArtifacts) {
 			getLog().debug(MessageFormat.format("Scanning artifact [{0}] for JAXB binding files.", artifact));
-			final File file = artifact.getFile();
-			ClassLoader classLoader = null;
-			try {
-				classLoader = new URLClassLoader(new URL[] { file.toURI().toURL() });
-			} catch (IOException ioex) {
-				throw new MojoExecutionException(
-						"Unable to create a classloader for the artifact file [" + file.getAbsolutePath() + "].", ioex);
-			}
-			JarFile jarFile = null;
-			try {
-				jarFile = new JarFile(file);
-				final Enumeration<JarEntry> jarFileEntries = jarFile.entries();
-				while (jarFileEntries.hasMoreElements()) {
-					JarEntry entry = jarFileEntries.nextElement();
-					if (entry.getName().endsWith(".xjb")) {
-						final URL resource = classLoader.getResource(entry.getName());
-						try {
-							bindingUris.add(resource.toURI());
-						} catch (URISyntaxException urisex) {
-							throw new MojoExecutionException(MessageFormat.format(
-									"Could not create the URI of the binding file from [{0}]", resource), urisex);
-						}
-					}
-				}
-			} catch (IOException ioex) {
-				throw new MojoExecutionException(
-						"Unable to read the artifact JAR file [" + file.getAbsolutePath() + "].", ioex);
-			} finally {
-				if (jarFile != null) {
+			collectBindingUrisFromArtifact(artifact.getFile(), bindingUris);
+		}
+	}
+
+	void collectBindingUrisFromArtifact(File file, List<URI> bindingUris) throws MojoExecutionException {
+		try (JarFile jarFile = new JarFile(file))
+		{
+			final Enumeration<JarEntry> jarFileEntries = jarFile.entries();
+			while (jarFileEntries.hasMoreElements()) {
+				JarEntry entry = jarFileEntries.nextElement();
+				if (entry.getName().endsWith(".xjb")) {
 					try {
-						jarFile.close();
-					} catch (IOException ignored) {
+						bindingUris.add(new URI("jar:" + file.toURI() + "!/" + entry.getName()));
+					} catch (URISyntaxException urisex) {
+						throw new MojoExecutionException(MessageFormat.format(
+								"Could not create the URI of the binding file from [{0}]", entry.getName()), urisex);
 					}
 				}
 			}
+		} catch (IOException ioex) {
+			throw new MojoExecutionException(
+					"Unable to read the artifact JAR file [" + file.getAbsolutePath() + "].", ioex);
 		}
 	}
 
@@ -840,8 +884,9 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 	/**
 	 * Creates an instance of catalog resolver.
 	 * 
-	 * @return
+	 * @return Instance of the catalog resolver.
 	 * @throws MojoExecutionException
+	 *             If catalog resolver cannot be instantiated.
 	 */
 	protected CatalogResolver createCatalogResolver() throws MojoExecutionException {
 		final CatalogManager catalogManager = new CatalogManager();
@@ -889,10 +934,10 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 
 	/**
 	 * @return true to indicate results are up-to-date, that is, when the latest
-	 *         from input files is earlier than the younger from the output
-	 *         files (meaning no re-execution required).
+	 *         from input files is earlier than the younger from the output files
+	 *         (meaning no re-execution required).
 	 */
-	protected boolean isUpToDate() throws MojoExecutionException {
+	protected boolean isUpToDate() {
 		final List<URI> dependsURIs = getDependsURIs();
 		final List<URI> producesURIs = getProducesURIs();
 
@@ -1036,12 +1081,11 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 	}
 
 	/**
-	 * Returns array of command line arguments for XJC. These arguments are
-	 * based on the configured arguments (see {@link #getArgs()}) but also
-	 * include episode arguments.
+	 * Returns array of command line arguments for XJC. These arguments are based on
+	 * the configured arguments (see {@link #getArgs()}) but also include episode
+	 * arguments.
 	 * 
 	 * @return String array of XJC command line options.
-	 * @throws MojoExecutionException
 	 */
 
 	protected List<String> getArguments() {
@@ -1114,7 +1158,8 @@ public abstract class RawXJC2Mojo<O> extends AbstractXJC2Mojo<O> {
 		final OptionsConfiguration optionsConfiguration = new OptionsConfiguration(getEncoding(), getSchemaLanguage(),
 				getGrammars(), getBindFiles(), getEntityResolver(), getGeneratePackage(), getGenerateDirectory(),
 				getReadOnly(), getPackageLevelAnnotations(), getNoFileHeader(), getEnableIntrospection(),
-				getDisableXmlSecurity(), getAccessExternalSchema(), getAccessExternalDTD(), getContentForWildcard(),
+				getDisableXmlSecurity(), getAccessExternalSchema(), getAccessExternalDTD(), isEnableExternalEntityProcessing(), 
+				getContentForWildcard(),
 				getExtension(), getStrict(), getVerbose(), getDebug(), getArguments(), getXjcPluginURLs(),
 				getSpecVersion());
 		return optionsConfiguration;
